
const { ccclass, property } = cc._decorator;

/**
 * 弹窗类窗体组件基类，提供弹窗类界面的弹出和关闭等一些管理方法，提供界面从弹出到关闭的方法生命周期维护
 * 
 */
export default abstract class UIBase extends cc.Component {

    onLoad(): void {
    }

    start(): void {
    }

    update(): void {

    }

    lateUpdate(): void {

    }

    onDestroy(): void {

    }

    onEnable(): void {

    }

    onDisable(): void {

    }

    /**
     * 显示方法，调用该方法会显示界面。
     * @param root 
     * @param param 
     * @param action 
     */
    public Show(root?: cc.Node) {

        if (!(cc.isValid(root) && this.isValid)) {
            //root = cc.director.getScene();
            root = cc.Canvas.instance.node;
        }

        root.addChild(this.node);

        this.InitShow();
        this.OnShow();
    }
    /**
     * 关闭
     * @param action 
     */
    public Close() {
        this.scheduleOnce(() => {
            this.CloseUI();
        });
    }
    protected CloseUI() {

        //cc.log(this.node.parent);
        this.node.removeFromParent(true);
        this.OnClose();

    }

    /**
     * 刷新
     */
    public InitShow() {
    }
    public OnShow() {
    }

    public OnClose() {

    }
    public BackClick() {
        this.CloseClick();
    }
    public OnKeyClick(value: cc.macro.KEY): boolean {
        return false;
    }
    public CloseClick() {
        this.Close();
    }
    public DestoryUi() {

    }

}